package com.fs.course.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.fs.course.domain.FsCourseRedPacketRetry;

/**
 * 课程红包失败重试记录Mapper接口
 * 
 * @author fs
 * @date 2025-03-18
 */
public interface FsCourseRedPacketRetryMapper extends BaseMapper<FsCourseRedPacketRetry>{
    /**
     * 查询课程红包失败重试记录
     * 
     * @param logId 课程红包失败重试记录主键
     * @return 课程红包失败重试记录
     */
    FsCourseRedPacketRetry selectFsCourseRedPacketRetryByLogId(Long logId);

    /**
     * 查询课程红包失败重试记录列表
     * 
     * @param fsCourseRedPacketRetry 课程红包失败重试记录
     * @return 课程红包失败重试记录集合
     */
    List<FsCourseRedPacketRetry> selectFsCourseRedPacketRetryList(FsCourseRedPacketRetry fsCourseRedPacketRetry);

    /**
     * 新增课程红包失败重试记录
     * 
     * @param fsCourseRedPacketRetry 课程红包失败重试记录
     * @return 结果
     */
    int insertFsCourseRedPacketRetry(FsCourseRedPacketRetry fsCourseRedPacketRetry);

    /**
     * 修改课程红包失败重试记录
     * 
     * @param fsCourseRedPacketRetry 课程红包失败重试记录
     * @return 结果
     */
    int updateFsCourseRedPacketRetry(FsCourseRedPacketRetry fsCourseRedPacketRetry);

    /**
     * 删除课程红包失败重试记录
     * 
     * @param logId 课程红包失败重试记录主键
     * @return 结果
     */
    int deleteFsCourseRedPacketRetryByLogId(Long logId);

    /**
     * 批量删除课程红包失败重试记录
     * 
     * @param logIds 需要删除的数据主键集合
     * @return 结果
     */
    int deleteFsCourseRedPacketRetryByLogIds(Long[] logIds);
}
